@@ -273,8 +273,25 @@ def import_new_jobs():
         local_job.logline("Job imported at %s" % datetime.datetime.now())
 
     if do_send_package_info:
-        # Send full package info to server.
-        upload_packages()
+        try:
+            # Send full package info to server.
+            upload_packages()
+        except Exception as e:
+            print >>os.sys.stderr, "Package upload failed" + str(e)
+
+
+def check_outstanding_packages():
+    # Get number of packages with updates and number of security updates.
+    # This is really a wrapper for apt-check.
+    try:
+        proc = subprocess.Popen(["/usr/lib/update-notifier/apt-check"],
+                                stderr=subprocess.PIPE, shell=True)
+        _, err = proc.communicate()
+        package_updates, security_updates = map(int, err.split(';'))
+        return (package_updates, security_updates)
+    except Exception as e:
+        print >>os.sys.stderr, "apt-check failed" + str(e)
+        return None
 
 
 def report_job_results(joblist):
@@ -282,7 +299,8 @@ def report_job_results(joblist):
         return
     (remote_url, uid) = get_url_and_uid()
     remote = BibOSAdmin(remote_url)
-    remote.send_status_info(uid, None, joblist)
+    remote.send_status_info(uid, None, joblist,
+                            update_required=check_outstanding_packages())
 
 
 def get_pending_job_dirs():
